#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
* Filename: __init__.py
* Description:
* Time: 2024.12.05
*/
"""

__name__ = 'zoomeyeai'
__package__ = 'zoomeyeai'
__version__ = 'v3.0.0'
__site__ = "https://www.zoomeye.ai/doc"
